
; Loading NCL libraries
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

begin

; index where to start extracting the data
icoup = 36

; Defining the two colormaps that will be used
; see http://www.ncl.ucar.edu/Document/Graphics/color_table_gallery.shtml
cmap1 = "BlueDarkRed18"
cmap2 = "GMT_copper"

; reading the NetCDF and extracting the density
fin = addfile("Isopycnal_TSplot_27_05_2016.nc", "r")
dens = fin->dens(icoup+1:, icoup+1:)
delete(fin)

; reading the other netcf
fin = addfile("Data4figures_annmean.nc", "r")

; data extraction
uspeer = fin->U_Speer(0, icoup+1:, icoup+1:)
vspeer = fin->V_Speer(0, icoup+1:, icoup+1:)
tsgs = fin->TS_GS_anmean(0, icoup+1:, icoup+1:)
uspeermix = fin->U_Speer_mix(0, icoup+1:, icoup+1:)
vspeermix = fin->V_Speer_mix(0, icoup+1:, icoup+1:)
dse = fin->dSE_TS_anmean(0, icoup+1:, icoup+1:)
dqsol = fin->dQsol_TS_anmean(0, icoup+1:, icoup+1:)
dqnsol = fin->dQnsol_TS_anmean(0, icoup+1:, icoup+1:)

; sum of solar + nonsolar flux
dqtot = dqsol + dqnsol

x = fin->Srange(icoup+1:)
y = fin->Trange(icoup+1:)

; Converting from Sv to mSv (is it ok?)
tsgs = tsgs*1000
uspeer = uspeer*1000
vspeer = vspeer*1000
uspeermix = uspeermix*1000
vspeermix = vspeermix*1000
dse = dse*1000
dqtot = dqtot*1000

; Opening the figure file. 
; replace pdf by ps, eps, png, etc
wks = gsn_open_wks("png", "fig_loic")

; merge the two colormaps
gsn_merge_colormaps(wks, cmap1, cmap2)

; create the array that will contain 3 graphic objects
; (used when panelling)
plotF=new(3,graphic)

; defining the levels for the pcolor, quiver and
; density plots (fspan = np.linspace)
lpcol = fspan(-0.6, 0.6, 11)
lquiv = fspan(0, 300, 21)
ldens = fspan(25, 35, 21) 

; Settings for the text
restxt = True
restxt@txFontHeightF=0.013

; Settings for the density plot
resdens = True
resdens@gsnDraw = False  ; prevents from drawing 
resdens@gsnFrame = False ; prenvents from creating a new page in the PDF
resdens@cnLinesOn=True  ; Drawing of contour lines
resdens@sfXArray = x  ; x coord
resdens@sfYArray = y  ; y coord
resdens@cnLevelSelectionMode = "ExplicitLevels" ; explicit labels
resdens@cnLevels = ldens ; labels definition
resdens@cnLineLabelFontHeightF  = 0.008  ; label height
resdens@cnInfoLabelOn =False  ; no information on labels
resdens@cnLineLabelsOn=True  ; line labels
resdens@gsnLeftString=""  ; remove the default behaviour (put the var. attribute as title)
resdens@gsnRightString=""

; Settings for Gibraltar pcolor
respcol = True
respcol@gsnFrame=False
respcol@gsnDraw=False
respcol@sfXArray = x
respcol@sfYArray = y
respcol@cnFillOn            = True ; filled contours
respcol@cnLinesOn           = False ; no lines
respcol@cnFillMode = "RasterFill"  ; Use Raster instead of contours (possible to use RasterFill or AreaFill)
respcol@gsnSpreadColors       = True ; spread colors 
respcol@gsnSpreadColorStart   = 2  ; first color of the colorbar to use (see at the bottom of the program)
respcol@gsnSpreadColorEnd     = 19 ; last color of the colorbar to use
; axis limits
respcol@trYMinF = 12.
respcol@trYMaxF = 18.
respcol@trXMinF = 36.
respcol@trXMaxF = 39.5
; level definition
respcol@cnLevelSelectionMode = "ExplicitLevels" ; explicit labels
respcol@cnLevels = lpcol ; labels definition
; heigth and width of the panels
respcol@vpWidthF=0.6
respcol@vpHeightF=0.19
; remove the automatic title
respcol@gsnLeftString=""
respcol@gsnRightString=""
respcol@lbLabelBarOn = False ; no label bar
respcol@cnLineLabelsOn = False  ; no line labels
respcol@cnInfoLabelOn =False  ; no information on labels
respcol@tmXBLabelsOn = False  ; no x-ticks
respcol@tiYAxisString = "Temperature (C)"  ; y-label
; fontsize for x/ylabels and ticks
respcol@tiXAxisFontHeightF = 0.01
respcol@tmXBLabelFontHeightF=0.01
respcol@tiYAxisFontHeightF = 0.01
respcol@tmYLLabelFontHeightF=0.01

; Settings for the quiver plots
resV = True
resV@gsnFrame=False
resV@gsnDraw=False
; x and y coords of the quivers
resV@vfXArray = x  
resV@vfYArray = y 
resV@vcRefMagnitudeF         = 100.      ; reference magnitude
resV@vcRefLengthF            = 0.01  ; length of the reference length    
resV@vcGlyphStyle            = "CurlyVector"  ; curly vectors
resV@vcMinDistanceF          = 0.015  ; minimum distance between arrows
resV@vcLineArrowThicknessF = 1.6 ;arrow thickness
resV@gsnSpreadColors       = True ; spread colors on
resV@gsnSpreadColorStart   = 69  ; first color to use in the quiver pcolor
resV@gsnSpreadColorEnd     = 20  ; last color to use in the quiver pcolor
resV@vcLevelSelectionMode = "ExplicitLevels" ; explicit labels
resV@vcLevels = lquiv ; labels definition
resV@vcRefAnnoOn=False  ; no quiver keys
resV@lbLabelFontHeightF=0.013 ; label font height
resV@lbTitleFontHeightF=0.013 ; title font height
resV@lbTitleString = "Transformation rate (mSv)"  ; cbar label
resV@lbOrientation = "Vertical"  ; cbar orientation
; settings in order to put the cbar label in the right place
resV@lbTitlePosition="Right"
resV@lbTitleAngleF=90
resV@lbTitleDirection="Across"

; ------------------------- After the settings, the plotting

; speed array
speed = sqrt(uspeer*uspeer + vspeer*vspeer)
pcol1 = gsn_csm_contour(wks, transpose(tsgs), respcol)  ; pcolor of TSGS
quiv1 = gsn_csm_vector_scalar(wks, transpose(uspeer), transpose(vspeer), transpose(speed), resV) ; quiver plot
dens1 = gsn_csm_contour(wks, dens, resdens)  ; density contour
overlay(quiv1, dens1)   ; overlay of the dens plot on the quiv plot
overlay(pcol1, quiv1)   ; overlay of the quiv plot on the pcol plot
dum1 = gsn_add_text(wks, pcol1, "Net", 36.25, 13.5, restxt)   ; adding the text
plotF(0) = pcol1   ; adding the pcol1 to the graphic array

; same thing as above
speedmix = sqrt(uspeermix*uspeermix + vspeermix*vspeermix)
pcol2 = gsn_csm_contour(wks, transpose(tsgs), respcol)
quiv2 = gsn_csm_vector_scalar(wks, transpose(uspeermix), transpose(vspeermix), transpose(speedmix), resV)
dens2 = gsn_csm_contour(wks, dens, resdens)
overlay(quiv2, dens2)
overlay(pcol2, quiv2)
dum2 = gsn_add_text(wks, pcol2, "Mixing", 36.25, 13.5, restxt)
plotF(1) = pcol2

resV@vcRefMagnitudeF         = 4      ; changing the reference magnitude
delete(resV@vcLevels)   ; deletion of the resV array (NCL handles memory in a shitty way)
resV@vcLevels=fspan(0,8,21)  ; definition of the new quiver levels
respcol@tmXBLabelsOn = True  ; reactivating the xticklabels
respcol@tiXAxisString = "Salinity (psu)"  ; adding the x-label
speeddQ = sqrt(dse*dse + dqtot*dqtot)
pcol3 = gsn_csm_contour(wks, transpose(tsgs), respcol)
quiv3 = gsn_csm_vector_scalar(wks, transpose(dse), transpose(dqtot), transpose(speeddQ), resV)
dens3 = gsn_csm_contour(wks, dens, resdens)
overlay(quiv3, dens3)
overlay(pcol3, quiv3)
dum3 = gsn_add_text(wks, pcol3, "Air-Sea", 36.25, 13.5, restxt)
plotF(2) = pcol3

; Setttings for the panel plot
resP=True 
resP@gsnPanelLabelBar = True  ; add common colorbar
resP@lbLabelFontHeightF=0.013 ; cbar font height
resP@lbTitleFontHeightF=0.013 ; cbar title font height
resP@gsnPanelYWhiteSpacePercent=1 ; panels height spacing
resP@lbTitleString = "Gibraltar flow (mSv)"  ; cbar title
resP@pmLabelBarOrthogonalPosF=-0.011 ; label bar orth. position (-: moving south)
resP@pmLabelBarWidthF=0.6  ; changing the width of the label bar
resP@lbTitlePosition="Bottom" ; title position at the bottom of the cbar
gsn_panel(wks, plotF, (/3, 1/), resP  )  ; drawing of panel (this commmand makes a "draw" and a "frame")

; In order to draw in the output the colors of the workstation and the associated indexes, uncomment below
; usefull in order to choose the proper values for the 
; gsnSpreadColorStart and   gsnSpreadColorEnd resources=
; gsn_draw_colormap(wks)

end


